@@ -25,7 +25,7 @@
 #include "viewportwidget.h"
 #include "functionedit.h"
 #ifdef HAVE_OPENGL
-#	include <analitzagui//plotsview3d.h>
+#	include <analitzagui/plotsview3d.h>
 #endif
 
 #include <analitzagui/operatorsmodel.h>
@@ -35,6 +35,7 @@
 #include <analitzaplot/plotsmodel.h>
 #include <analitzaplot/functiongraph.h>
 #include <analitzaplot/planecurve.h>
+#include <analitzaplot/plotsfactory.h>
 #include <analitza/variables.h>
 #include <analitza/value.h>
 
@@ -43,21 +44,21 @@
 #include <QDockWidget>
 #include <QTableView>
 #include <QPrinter>
-#include <KAction>
-#include <KHTMLView>
+#include <QAction>
+#include <QFileDialog>
+#include <QStatusBar>
+#include <QMenuBar>
+#include <QToolButton>
+#include <QApplication>
+#include <klocalizedstring.h>
 #include <KHelpMenu>
-#include <KFileDialog>
-#include <KMenu>
-#include <KMenuBar>
-#include <KStatusBar>
-#include <KLocale>
 #include <KStandardAction>
-#include <KProcess>
-#include <KRecentFilesAction>
-#include <KApplication>
 #include <KToggleFullScreenAction>
-#include <kabstractfilewidget.h>
-#include <analitzaplot/plotsfactory.h>
+#include <KRecentFilesAction>
+#include <kconfig.h>
+#include <QProcess>
+#include <QPointer>
+#include <kconfiggroup.h>
 
 class Add2DOption : public InlineOptions
 {
@@ -67,7 +68,7 @@ class Add2DOption : public InlineOptions
 		{}
 		
 		virtual QString id() const { return "add2d"; }
-		virtual bool matchesExpression(const Analitza::Expression& exp, const Analitza::ExpressionType& functype) const {
+		virtual bool matchesExpression(const Analitza::Expression& exp, const Analitza::ExpressionType& /*functype*/) const {
 			return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim2D).canDraw();
 		}
 
@@ -88,7 +89,7 @@ class Add3DOption : public InlineOptions
 		{}
 		
 		virtual QString id() const { return "add3d"; }
-		virtual bool matchesExpression(const Analitza::Expression& exp, const Analitza::ExpressionType& functype) const
+		virtual bool matchesExpression(const Analitza::Expression& exp, const Analitza::ExpressionType& /*functype*/) const
 		{
 			return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D).canDraw();
 		}
@@ -104,15 +105,16 @@ class Add3DOption : public InlineOptions
 
 QColor randomFunctionColor() { return QColor::fromHsv(qrand()%255, 255, 255); }
 
-KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
+KAlgebra::KAlgebra(QWidget *parent)
+	: QMainWindow(parent)
 {
 	resize(900, 500);
 	
 	m_tabs = new QTabWidget;
 	setCentralWidget(m_tabs);
 	
-	setStatusBar(new KStatusBar(this));
-	setMenuBar(new KMenuBar(this));
+	setStatusBar(new QStatusBar(this));
+	setMenuBar(new QMenuBar(this));
 	
 	KToggleFullScreenAction* fullScreenAction = KStandardAction::fullScreen(this, SLOT(fullScreen(bool)), this, this);
 	
@@ -167,15 +169,15 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	////////menu
 	c_menu = menuBar()->addMenu(i18n("C&onsole"));
 	
-	c_menu->addAction(KIcon("document-open"), i18nc("@item:inmenu", "&Load Script..."),
+	c_menu->addAction(QIcon::fromTheme("document-open"), i18nc("@item:inmenu", "&Load Script..."),
 						this, SLOT(loadScript()), Qt::CTRL+Qt::Key_L);
-	c_recentScripts=new KRecentFilesAction(KIcon("document-open-recent"), i18n("Recent Scripts"), this);
-	connect(c_recentScripts, SIGNAL(urlSelected(KUrl)), this, SLOT(loadScript(KUrl)));
+	c_recentScripts=new KRecentFilesAction(QIcon::fromTheme("document-open-recent"), i18n("Recent Scripts"), this);
+	connect(c_recentScripts, SIGNAL(urlSelected(QUrl)), this, SLOT(loadScript(QUrl)));
 	c_menu->addAction(c_recentScripts);
 	
-	c_menu->addAction(KIcon("document-save"), i18nc("@item:inmenu", "&Save Script..."),
+	c_menu->addAction(QIcon::fromTheme("document-save"), i18nc("@item:inmenu", "&Save Script..."),
 						this, SLOT(saveScript()), Qt::CTRL+Qt::Key_G);
-	c_menu->addAction(KIcon("document-save"), i18nc("@item:inmenu", "&Export Log..."),
+	c_menu->addAction(QIcon::fromTheme("document-save"), i18nc("@item:inmenu", "&Export Log..."),
 						this, SLOT(saveLog()), QKeySequence::Save);
 	c_menu->addSeparator()->setText(i18n("Execution Mode"));
 	QActionGroup *execGroup = new QActionGroup(c_menu);
@@ -218,7 +220,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	b_funced->setVariables(c_varsModel->variables());
 	connect(b_funced, SIGNAL(accept()), this, SLOT(new_func()));
 	connect(b_funced, SIGNAL(removeEditingPlot()), this, SLOT(remove_func()));
-	b_tools->addTab(b_funced, KIcon("list-add"), i18n("&Add"));
+	b_tools->addTab(b_funced, QIcon::fromTheme("list-add"), i18n("&Add"));
 	
 	QTableView* b_varsView=new QTableView(b_tools);
 	b_varsModel=new Analitza::VariablesModel(b_funced->variables());
@@ -258,7 +260,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	b_menu->addSeparator();
 	b_menu->addAction(KStandardAction::zoomIn(m_graph2d, SLOT(zoomIn()), this));
 	b_menu->addAction(KStandardAction::zoomOut(m_graph2d, SLOT(zoomOut()), this));
-	KAction* ac=KStandardAction::actualSize(m_graph2d, SLOT(resetViewport()), this);
+	QAction* ac=KStandardAction::actualSize(m_graph2d, SLOT(resetViewport()), this);
 	ac->setShortcut(Qt::ControlModifier + Qt::Key_0);
 	b_menu->addAction(ac);
 	b_menu->addSeparator()->setText(i18n("Resolution"));
@@ -292,7 +294,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	QWidget *tridim = new QWidget(m_tabs);
 	QVBoxLayout *t_layo = new QVBoxLayout(tridim);
 	t_exp = new Analitza::ExpressionEdit(tridim);
-	t_exp->setExamples(QStringList() << "sin x+sin y" << "(x,y)->x" << "x*y");
+	t_exp->setExamples(Analitza::PlotsFactory::self()->examples(Analitza::Dim3D));
 	t_exp->setAns("x");
 	t_model3d = new Analitza::PlotsModel(this);
 	m_graph3d = new Analitza::PlotsView3D(tridim);
@@ -311,7 +313,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	t_menu = menuBar()->addMenu(i18n("3D &Graph"));
 	QAction* t_actions[5];
 	t_menu->addAction(KStandardAction::save(this, SLOT(save3DGraph()), this));
-	t_menu->addAction(KIcon("zoom-original"), i18n("&Reset View"), m_graph3d, SLOT(resetView()));
+	t_menu->addAction(QIcon::fromTheme("zoom-original"), i18n("&Reset View"), m_graph3d, SLOT(resetView()));
 	t_menu->addSeparator();
 	t_actions[2] = t_menu->addAction(i18n("Dots"), this, SLOT(set_dots()));
 	t_actions[3] = t_menu->addAction(i18n("Lines"), this, SLOT(set_lines()));
@@ -340,8 +342,7 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	
 	QWidget *w=new QWidget;
 	QLayout *leftLayo=new QVBoxLayout(w);
-	d_filter=new KLineEdit(w);
-	d_filter->setClearButtonShown(true);
+	d_filter=new QLineEdit(w);
 	d_filter->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
 	connect(d_filter, SIGNAL(textChanged(QString)), dic, SLOT(setFilter(QString)));
 	connect(d_filter, SIGNAL(textChanged(QString)), this, SLOT(dictionaryFilterChanged(QString)));
@@ -358,10 +359,10 @@ KAlgebra::KAlgebra(QWidget *parent) : KMainWindow(parent)
 	
 	//EODictionary
 	//Ego's reminder
-	KHelpMenu* help = new KHelpMenu(this, KGlobal::mainComponent().aboutData());
+	KHelpMenu* help = new KHelpMenu(this);
 	menuBar()->addMenu(help->menu());
 
-#warning TODO: Port to PlotsModel
+#pragma message("TODO: Port to PlotsModel")
 // 	connect(b_funcsModel, SIGNAL(functionModified(QString,Analitza::Expression)),
 // 			c_results, SLOT(modifyVariable(QString,Analitza::Expression)));
 // 	connect(b_funcsModel, SIGNAL(functionRemoved(QString)),
@@ -376,8 +377,8 @@ KAlgebra::~KAlgebra()
 	KConfig conf("kalgebrarc");
 	KConfigGroup config(&conf, "Default");
 	QStringList urls;
-	foreach(const KUrl& url, c_recentScripts->urls())
-		urls += url.prettyUrl();
+	foreach(const QUrl& url, c_recentScripts->urls())
+		urls += url.toDisplayString();
 	
 	config.writeEntry("recent", urls);
 }
@@ -389,13 +390,13 @@ void KAlgebra::initializeRecentScripts()
 	
 	QStringList urls=config.readEntry("recent", QStringList());
 	foreach(const QString& url, urls) {
-		c_recentScripts->addUrl(KUrl(url));
+		c_recentScripts->addUrl(QUrl(url));
 	}
 }
 
 void KAlgebra::newInstance()
 {
-	KProcess::startDetached(QApplication::applicationFilePath());
+	QProcess::startDetached(QApplication::applicationFilePath());
 }
 
 void KAlgebra::add2D(const Analitza::Expression& exp)
@@ -498,13 +499,13 @@ void KAlgebra::changeStatusBar(const QString& msg)
 
 void KAlgebra::loadScript()
 {
-	KUrl path = KFileDialog::getOpenUrl(KUrl(), "*.kal|"+i18n("Script (*.kal)"), this, i18n("Choose a script"));
+	QUrl path = QFileDialog::getOpenFileUrl(this, i18n("Choose a script"), QUrl(), "*.kal|"+i18n("Script (*.kal)"));
 	
 	if(!path.isEmpty())
 		loadScript(path);
 }
 
-void KAlgebra::loadScript(const KUrl& path)
+void KAlgebra::loadScript(const QUrl& path)
 {
 	bool loaded=c_results->loadScript(path);
 	
@@ -514,7 +515,7 @@ void KAlgebra::loadScript(const KUrl& path)
 
 void KAlgebra::saveScript()
 {
-	KUrl path = KFileDialog::getSaveUrl(KUrl(), "*.kal|"+i18n("Script (*.kal)"), this, QString(), KFileDialog::ConfirmOverwrite);
+	QUrl path = QFileDialog::getSaveFileUrl(this, QString(), QUrl(), "*.kal|"+i18n("Script (*.kal)"));
 	bool loaded=false;
 	if(!path.isEmpty())
 		loaded=c_results->saveScript(path);
@@ -525,7 +526,7 @@ void KAlgebra::saveScript()
 
 void KAlgebra::saveLog()
 {
-	KUrl path = KFileDialog::getSaveUrl(KUrl(), "*.html|"+i18n("HTML File (*.html)"), this, QString(), KFileDialog::ConfirmOverwrite);
+	QUrl path = QFileDialog::getSaveFileUrl(this, QString(), QUrl(), "*.html|"+i18n("HTML File (*.html)"));
 	if(!path.isEmpty())
 		c_results->saveLog(path);
 }
@@ -572,10 +573,12 @@ void KAlgebra::set_solid()
 void KAlgebra::save3DGraph()
 {
 #ifdef HAVE_OPENGL
-	QString path = KFileDialog::getSaveFileName(KUrl(), i18n("*.png|PNG File\n*.pdf|PDF Document"), this, QString(), KFileDialog::ConfirmOverwrite);
+	QString path = QFileDialog::getSaveFileName(this, QString(), QString(), i18n("*.png|PNG File\n*.pdf|PDF Document\n*.x3d|X3D Document"));
 	if(!path.isEmpty()) {
-		QPixmap px = m_graph3d->renderPixmap();
-		if(path.endsWith(".pdf")) {
+		if(path.endsWith(".x3d")) {
+			m_graph3d->exportSurfaces(path);
+		} else if(path.endsWith(".pdf")) {
+			QPixmap px = m_graph3d->renderPixmap();
 			QPrinter printer;
 			printer.setOutputFormat(QPrinter::PdfFormat);
 			printer.setOutputFileName(path);
@@ -586,6 +589,7 @@ void KAlgebra::save3DGraph()
 			painter.drawPixmap(QPoint(0,0), px);
 			painter.end();
 		} else {
+			QPixmap px = m_graph3d->renderPixmap();
 			px.save(path);
 		}
 	}
@@ -594,7 +598,7 @@ void KAlgebra::save3DGraph()
 
 void KAlgebra::toggleSquares()
 {
-	m_graph2d->setShowGrid(!m_graph2d->showGrid());
+	m_graph2d->setTicksShown(m_graph2d->ticksShown() ? (Qt::Horizontal|Qt::Vertical) : ~(Qt::Horizontal|Qt::Vertical));
 }
 
 void KAlgebra::toggleKeepAspect()
@@ -604,13 +608,12 @@ void KAlgebra::toggleKeepAspect()
 
 void KAlgebra::saveGraph()
 {
-	QPointer<KFileDialog> dialog=new KFileDialog(KUrl(), i18n("*.png|Image File\n*.svg|SVG File"), this);
-	dialog->setOperationMode(KFileDialog::Saving);
+    QPointer<QFileDialog> dialog=new QFileDialog(this, i18n("Select where to put the rendered plot"), QString(), i18n("*.png|Image File\n*.svg|SVG File"));
 	dialog->setConfirmOverwrite(true);
 	
-	if(dialog->exec()) {
-		QString filter = dialog->fileWidget()->currentFilter();
-		QString filename = dialog->selectedFile();
+	if(dialog->exec() && !dialog->selectedFiles().isEmpty()) {
+		QString filter = dialog->selectedNameFilter();
+		QString filename = dialog->selectedFiles().first();
 		
 		bool isSvg = filename.endsWith(".svg") || (!filename.endsWith(".png") && filter.mid(2, 3)=="svg");
 		Analitza::PlotsView2D::Format f = isSvg ? Analitza::PlotsView2D::SVG : Analitza::PlotsView2D::PNG;
