@@ -19,13 +19,12 @@
 #ifndef KALGEBRA_H
 #define KALGEBRA_H
 
-#include <KMainWindow>
-#include <KLineEdit>
 #include <QTreeView>
 #include <QPushButton>
 #include <QTabWidget>
 #include <QLabel>
 #include <QListView>
+#include <QMainWindow>
 #include <config-kalgebra.h>
 
 namespace Analitza {
@@ -42,7 +41,7 @@ class KRecentFilesAction;
 
 namespace Analitza { class Expression; }
 
-class KAlgebra : public KMainWindow
+class KAlgebra : public QMainWindow
 {
 	Q_OBJECT
 	public:
@@ -84,16 +83,16 @@ class KAlgebra : public KMainWindow
 		//Dictionary
 		QDockWidget *d_dock;
 		QListView *d_list;
-		KLineEdit *d_filter;
+		QLineEdit *d_filter;
 		
-	private slots:
+	private Q_SLOTS:
 		void newInstance();
 		void fullScreen(bool isFull);
 		
 		void initializeRecentScripts();
 		void operate();
 		void loadScript();
-		void loadScript(const KUrl& path);
+		void loadScript(const QUrl& path);
 		void saveScript();
 		void saveLog();
 		void updateInformation();
